==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/RedstoneRequesterConfigurationPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import io.netty.buffer.ByteBuf;
import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record RedstoneRequesterConfigurationPacket(
    class_2338 pos, String address, boolean allowPartial, List<Integer> amounts
) implements class_2596<class_2792> {
    public static final class_9139<ByteBuf, RedstoneRequesterConfigurationPacket> CODEC = class_9139.method_56905(
        class_2338.field_48404,
        RedstoneRequesterConfigurationPacket::pos,
        class_9135.field_48554,
        RedstoneRequesterConfigurationPacket::address,
        class_9135.field_48547,
        RedstoneRequesterConfigurationPacket::allowPartial,
        CatnipStreamCodecBuilders.list(class_9135.field_49675),
        RedstoneRequesterConfigurationPacket::amounts,
        RedstoneRequesterConfigurationPacket::new
    );

    @Override
    public void handle(class_2792 listener) {
        AllHandle.onRedstoneRequesterConfiguration((class_3244) listener, this);
    }

    @Override
    public class_9145<RedstoneRequesterConfigurationPacket> method_65080() {
        return AllPackets.CONFIGURE_REDSTONE_REQUESTER;
    }
}

==> create-fly-6.0.7-1.21.8-19-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/RedstoneRequesterConfigurationPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import io.netty.buffer.ByteBuf;
import java.util.List;
import java.util.function.BiConsumer;
import net.minecraft.class_2338;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record RedstoneRequesterConfigurationPacket(class_2338 pos, String address, boolean allowPartial, List<Integer> amounts) implements C2SPacket {
    public static final class_9139<ByteBuf, RedstoneRequesterConfigurationPacket> CODEC = class_9139.method_56905(
        class_2338.field_48404,
        RedstoneRequesterConfigurationPacket::pos,
        class_9135.field_48554,
        RedstoneRequesterConfigurationPacket::address,
        class_9135.field_48547,
        RedstoneRequesterConfigurationPacket::allowPartial,
        CatnipStreamCodecBuilders.list(class_9135.field_49675),
        RedstoneRequesterConfigurationPacket::amounts,
        RedstoneRequesterConfigurationPacket::new
    );

    @Override
    public boolean runInMain() {
        return true;
    }

    @Override
    public class_9145<RedstoneRequesterConfigurationPacket> method_65080() {
        return AllPackets.CONFIGURE_REDSTONE_REQUESTER;
    }

    @Override
    public BiConsumer<class_3244, RedstoneRequesterConfigurationPacket> callback() {
        return AllHandle::onRedstoneRequesterConfiguration;
    }
}
